pub struct DLLCharacteristics { /* private fields */ }Expand description
A series of bitflags representing DLL characteristics.
Implementations
Sourceimpl DLLCharacteristics
impl DLLCharacteristics
pub const RESERVED1: DLLCharacteristics
pub const RESERVED2: DLLCharacteristics
pub const RESERVED4: DLLCharacteristics
pub const RESERVED8: DLLCharacteristics
pub const HIGH_ENTROPY_VA: DLLCharacteristics
pub const DYNAMIC_BASE: DLLCharacteristics
pub const FORCE_INTEGRITY: DLLCharacteristics
pub const NX_COMPAT: DLLCharacteristics
pub const NO_ISOLATION: DLLCharacteristics
pub const NO_SEH: DLLCharacteristics
pub const NO_BIND: DLLCharacteristics
pub const APPCONTAINER: DLLCharacteristics
pub const WDM_DRIVER: DLLCharacteristics
pub const GUARD_CF: DLLCharacteristics
pub const TERMINAL_SERVER_AWARE: DLLCharacteristics
Sourcepub const fn empty() -> DLLCharacteristics
pub const fn empty() -> DLLCharacteristics
Returns an empty set of flags
Sourcepub const fn all() -> DLLCharacteristics
pub const fn all() -> DLLCharacteristics
Returns the set containing all flags.
Sourcepub fn from_bits(bits: u16) -> Option<DLLCharacteristics>
pub fn from_bits(bits: u16) -> Option<DLLCharacteristics>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: u16) -> DLLCharacteristics
pub const fn from_bits_truncate(bits: u16) -> DLLCharacteristics
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: u16) -> DLLCharacteristics
pub const unsafe fn from_bits_unchecked(bits: u16) -> DLLCharacteristics
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Sourcepub const fn intersects(&self, other: DLLCharacteristics) -> bool
pub const fn intersects(&self, other: DLLCharacteristics) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: DLLCharacteristics) -> bool
pub const fn contains(&self, other: DLLCharacteristics) -> bool
Returns true all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: DLLCharacteristics)
pub fn insert(&mut self, other: DLLCharacteristics)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: DLLCharacteristics)
pub fn remove(&mut self, other: DLLCharacteristics)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: DLLCharacteristics)
pub fn toggle(&mut self, other: DLLCharacteristics)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: DLLCharacteristics, value: bool)
pub fn set(&mut self, other: DLLCharacteristics, value: bool)
Inserts or removes the specified flags depending on the passed value.