This module only exports a single function. It’s used to contain metadata used to perform the imphash algorithm.
Functions
- imphash_
resolve - Resolve the given ordinal and DLL name according to the imphash algorithm.
This module only exports a single function. It’s used to contain metadata used to perform the imphash algorithm.