pub struct VSHeader {
pub length: u16,
pub value_length: u16,
pub type_: u16,
pub key: Vec<WChar>,
}Expand description
Represents a header for a VS_VERSION structure.
This is not an officially documented header, but rather is added to make parsing these aspects of the structures a little bit easier.
Fields
length: u16value_length: u16type_: u16key: Vec<WChar>Implementations