pub struct AllocationType { /* private fields */ }Expand description
Only available for Windows. Represents the bitflags for flAllocationType in VirtualAlloc.
Implementations
Sourceimpl AllocationType
impl AllocationType
pub const MEM_COMMIT: AllocationType
pub const MEM_RESERVE: AllocationType
pub const MEM_RESET: AllocationType
pub const MEM_RESET_UNDO: AllocationType
pub const MEM_LARGE_PAGES: AllocationType
pub const MEM_PHYSICAL: AllocationType
pub const MEM_TOP_DOWN: AllocationType
pub const MEM_WRITE_WATCH: AllocationType
Sourcepub const fn empty() -> AllocationType
pub const fn empty() -> AllocationType
Returns an empty set of flags
Sourcepub const fn all() -> AllocationType
pub const fn all() -> AllocationType
Returns the set containing all flags.
Sourcepub fn from_bits(bits: u32) -> Option<AllocationType>
pub fn from_bits(bits: u32) -> Option<AllocationType>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: u32) -> AllocationType
pub const fn from_bits_truncate(bits: u32) -> AllocationType
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> AllocationType
pub const unsafe fn from_bits_unchecked(bits: u32) -> AllocationType
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Sourcepub const fn intersects(&self, other: AllocationType) -> bool
pub const fn intersects(&self, other: AllocationType) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: AllocationType) -> bool
pub const fn contains(&self, other: AllocationType) -> bool
Returns true all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: AllocationType)
pub fn insert(&mut self, other: AllocationType)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: AllocationType)
pub fn remove(&mut self, other: AllocationType)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: AllocationType)
pub fn toggle(&mut self, other: AllocationType)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: AllocationType, value: bool)
pub fn set(&mut self, other: AllocationType, value: bool)
Inserts or removes the specified flags depending on the passed value.